* Demonstration Abhaengigkeit Beta von Schiefe
version 9

preserve

* Wait! I need to calculate 1000 regression-models
quietly {

    * make data
    clear
    set obs 1000

    * X1-Variable (skewness constant)
    gen X1 = 0 in 1/500
    replace X1 = 1 in 501/1000
    sum X1
    local sx1 = r(sd)

    * Errors (standard normal distributed)
    set seed 731
    gen error = invnormal(uniform())

    * Sort Data at random to reduce multicollinarity
    gen r = uniform()
    sort r

    * generate empty X2 and Y 
    gen X2 = .
    gen Y = .

    * Postfile
    postfile betas b1 b2 promill beta1 beta2 using betas, replace

    * Loop
    forv i = 2/999 {
        * Generate X2
        replace X2 = 0
        replace X2 = 1 in 1/`i'
        summarize X2, detail
        local sx2 = r(sd)

        * Generate Y with b-coefficent of 2
        replace Y = 2 * X1 + 2 * X2 + error
        summarize Y
        local sy = r(sd)

        * calculate Regression
        regress Y X1 X2

        * Save Results
        post betas (_b[X1]) (_b[X2]) (`i++') (_b[X1] * `sx1'/`sy') (_b[X2] * `sx2'/`sy')
    }
    postclose betas

    use betas, clear

    * Graphik-labels
    lab var beta1 "Constant Skewness"
    lab var beta2 "Varible Skewness"

    lab var promill "freq of 1 in X2 (in 0/00)"

		graph twoway ///
		  (line beta1 beta2 promill, clstyle(p1 p2)) ///
		  , ytitle(Beta-Coef) title("Standardized b in Y = 2*X1 + 2*X2 + e") ///
		    xline(500) 
}

restore

exit
